"""
Module: markdown_parser.py
----------------------------
Jednoduch Markdown parser pro curses.
Rozpozn zkladn znaky:
  - **tun**  curses.A_BOLD
  - *kurzva*  curses.A_UNDERLINE
  - `kd`  curses.A_REVERSE (pro zvraznn kdu)
Vrac seznam segment ve tvaru (text, atribut), kter lze postupn vypsat pomoc curses.
"""

import re
import curses

def parse_markdown(text):
    """
    Rozparsuje zadan text obsahujc jednoduch Markdown znaky a vrt seznam
    dvojic (segment_text, attribute). Nepodporuje vnoen znaky.

    Podporovan znaky:
      **text**  tun (A_BOLD)
      *text*    kurzva (A_UNDERLINE)
      `text`    kd (A_REVERSE)

    Pokud se znaky nepruj, vrac zbytek textu s atributem 0.
    """
    segments = []
    pos = 0
    pattern = re.compile(r'(\*\*.*?\*\*|\*.*?\*|`.*?`)')
    for match in pattern.finditer(text):
        start, end = match.span()
        # Normaln text ped znakou
        if start > pos:
            segments.append((text[pos:start], 0))
        token = match.group(0)
        # Rozpoznn typu tokenu
        if token.startswith("**") and token.endswith("**"):
            # Bold  odstranme dvojit hvzdiky
            content = token[2:-2]
            segments.append((content, curses.A_BOLD))
        elif token.startswith("*") and token.endswith("*"):
            # Italic  odstranme hvzdiky
            content = token[1:-1]
            segments.append((content, curses.A_UNDERLINE))
        elif token.startswith("`") and token.endswith("`"):
            # Inline kd  odstranme zptn apostrofy a pouijeme reverzn barvu
            content = token[1:-1]
            segments.append((content, curses.A_REVERSE))
        else:
            segments.append((token, 0))
        pos = end
    # Zbytek textu
    if pos < len(text):
        segments.append((text[pos:], 0))
    return segments

if __name__ == "__main__":
    # Jednoduch test
    sample = "Toto je **tun text**, toto je *kurzva* a toto je `kd`."
    segments = parse_markdown(sample)
    for seg, attr in segments:
        print(f"Segment: '{seg}', Attr: {attr}")
